[openib-general] [PATCH 21 of 53] ipath - use phys_to_virt instead of bus_to_virt

Bryan O'Sullivan bos at pathscale.com
Fri May 12 16:43:06 PDT 2006


I think Roland already has this patch.

diff -r 201654fe1962 -r 4e0a07d20868 drivers/infiniband/hw/ipath/ipath_keys.c
--- a/drivers/infiniband/hw/ipath/ipath_keys.c	Fri May 12 15:55:28 2006 -0700
+++ b/drivers/infiniband/hw/ipath/ipath_keys.c	Fri May 12 15:55:28 2006 -0700
@@ -126,11 +126,11 @@ int ipath_lkey_ok(struct ipath_lkey_tabl
 	/*
 	 * We use LKEY == zero to mean a physical kmalloc() address.
 	 * This is a bit of a hack since we rely on dma_map_single()
 	 * being reversible by calling bus_to_virt().
 	 */
 	if (sge->lkey == 0) {
 		isge->mr = NULL;
-		isge->vaddr = bus_to_virt(sge->addr);
+		isge->vaddr = phys_to_virt(sge->addr);
 		isge->length = sge->length;
 		isge->sge_length = sge->length;
 		ret = 1;
@@ -126,11 +126,11 @@ int ipath_lkey_ok(struct ipath_lkey_tabl
 	 * We use LKEY == zero to mean a physical kmalloc() address.
 	 * This is a bit of a hack since we rely on dma_map_single()
-	 * being reversible by calling bus_to_virt().
+	 * being reversible by calling phys_to_virt().
 	 */
 	if (sge->lkey == 0) {



More information about the general mailing list